==> jc-1.4.0.tar.gz: gnu/java/beans/editors/NativeFloatEditor.h <==
// public class gnu.java.beans.editors.NativeFloatEditor

// class file dependencies
// @dep_class 4049ce6ad369c931 gnu_java_beans_editors_NativeFloatEditor
// @dep_class 5a63ffefcb362768 java_beans_PropertyEditorSupport
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_beans_PropertyEditorSupport

#include "java/beans/PropertyEditorSupport.h"

#ifndef _JC_gnu_java_beans_editors_NativeFloatEditor_H_
#define _JC_gnu_java_beans_editors_NativeFloatEditor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_editors_NativeFloatEditor$sub_refs	_jc_gnu_java_beans_editors_NativeFloatEditor$sub_refs;
typedef struct _jc_gnu_java_beans_editors_NativeFloatEditor$sub_nonrefs	_jc_gnu_java_beans_editors_NativeFloatEditor$sub_nonrefs;
typedef struct _jc_gnu_java_beans_editors_NativeFloatEditor$refs	_jc_gnu_java_beans_editors_NativeFloatEditor$refs;
typedef struct _jc_gnu_java_beans_editors_NativeFloatEditor$nonrefs	_jc_gnu_java_beans_editors_NativeFloatEditor$nonrefs;
typedef struct _jc_gnu_java_beans_editors_NativeFloatEditor$object	_jc_gnu_java_beans_editors_NativeFloatEditor$object;

typedef const struct _jc_gnu_java_beans_editors_NativeFloatEditor$vmethods	_jc_gnu_java_beans_editors_NativeFloatEditor$vmethods;
typedef const struct _jc_gnu_java_beans_editors_NativeFloatEditor$vtable	_jc_gnu_java_beans_editors_NativeFloatEditor$vtable;
typedef const struct _jc_gnu_java_beans_editors_NativeFloatEditor$vtype	_jc_gnu_java_beans_editors_NativeFloatEditor$vtype;

// Constructors
extern void _jc_gnu_java_beans_editors_NativeFloatEditor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_beans_editors_NativeFloatEditor$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_beans_editors_NativeFloatEditor$method$getAsText$e78133031f0dd45a(_jc_env *, struct _jc_gnu_java_beans_editors_NativeFloatEditor$object *);
extern void _jc_gnu_java_beans_editors_NativeFloatEditor$method$setAsText$3108622962800f9f(_jc_env *, struct _jc_gnu_java_beans_editors_NativeFloatEditor$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_editors_NativeFloatEditor$method_info$getAsText$e78133031f0dd45a;
extern _jc_method _jc_gnu_java_beans_editors_NativeFloatEditor$method_info$setAsText$3108622962800f9f;

// Virtual methods structure
struct _jc_gnu_java_beans_editors_NativeFloatEditor$vmethods {
	struct _jc_java_lang_String$object	*(*getAsText$e78133031f0dd45a)(_jc_env *, struct _jc_gnu_java_beans_editors_NativeFloatEditor$object *);
	void	(*setAsText$3108622962800f9f)(_jc_env *, struct _jc_gnu_java_beans_editors_NativeFloatEditor$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_java_beans_editors_NativeFloatEditor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_PropertyEditorSupport$vmethods	java_beans_PropertyEditorSupport;
	_jc_gnu_java_beans_editors_NativeFloatEditor$vmethods	gnu_java_beans_editors_NativeFloatEditor;
};

// Vtype
struct _jc_gnu_java_beans_editors_NativeFloatEditor$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_editors_NativeFloatEditor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_editors_NativeFloatEditor$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_editors_NativeFloatEditor$refs {
    _jc_gnu_java_beans_editors_NativeFloatEditor$sub_refs	gnu_java_beans_editors_NativeFloatEditor;
    _jc_java_beans_PropertyEditorSupport$sub_refs	java_beans_PropertyEditorSupport;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_editors_NativeFloatEditor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_editors_NativeFloatEditor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_PropertyEditorSupport$sub_nonrefs	java_beans_PropertyEditorSupport;
    _jc_gnu_java_beans_editors_NativeFloatEditor$sub_nonrefs	gnu_java_beans_editors_NativeFloatEditor;
};

// Object instance structure
struct _jc_gnu_java_beans_editors_NativeFloatEditor$object {
	_jc_gnu_java_beans_editors_NativeFloatEditor$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_editors_NativeFloatEditor$vtype	*vtype;
	_jc_gnu_java_beans_editors_NativeFloatEditor$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_editors_NativeFloatEditor$vtype _jc_gnu_java_beans_editors_NativeFloatEditor$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_editors_NativeFloatEditor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_editors_NativeFloatEditor$class_object;

#endif	/* _JC_gnu_java_beans_editors_NativeFloatEditor_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/editors/NativeFloatEditor.h <==
// public class gnu.java.beans.editors.NativeFloatEditor

// class file dependencies
// @dep_class 4049ce6ad369c931 gnu_java_beans_editors_NativeFloatEditor
// @dep_class 5a63ffefcb362768 java_beans_PropertyEditorSupport
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_beans_PropertyEditorSupport

#include "java/beans/PropertyEditorSupport.h"

#ifndef _JC_gnu_java_beans_editors_NativeFloatEditor_H_
#define _JC_gnu_java_beans_editors_NativeFloatEditor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_editors_NativeFloatEditor$sub_refs	_jc_gnu_java_beans_editors_NativeFloatEditor$sub_refs;
typedef struct _jc_gnu_java_beans_editors_NativeFloatEditor$sub_nonrefs	_jc_gnu_java_beans_editors_NativeFloatEditor$sub_nonrefs;
typedef struct _jc_gnu_java_beans_editors_NativeFloatEditor$refs	_jc_gnu_java_beans_editors_NativeFloatEditor$refs;
typedef struct _jc_gnu_java_beans_editors_NativeFloatEditor$nonrefs	_jc_gnu_java_beans_editors_NativeFloatEditor$nonrefs;
typedef struct _jc_gnu_java_beans_editors_NativeFloatEditor$object	_jc_gnu_java_beans_editors_NativeFloatEditor$object;

typedef const struct _jc_gnu_java_beans_editors_NativeFloatEditor$vmethods	_jc_gnu_java_beans_editors_NativeFloatEditor$vmethods;
typedef const struct _jc_gnu_java_beans_editors_NativeFloatEditor$vtable	_jc_gnu_java_beans_editors_NativeFloatEditor$vtable;
typedef const struct _jc_gnu_java_beans_editors_NativeFloatEditor$vtype	_jc_gnu_java_beans_editors_NativeFloatEditor$vtype;

// Constructors
extern void _jc_gnu_java_beans_editors_NativeFloatEditor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_beans_editors_NativeFloatEditor$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_beans_editors_NativeFloatEditor$method$getAsText$e78133031f0dd45a(_jc_env *, struct _jc_gnu_java_beans_editors_NativeFloatEditor$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_editors_NativeFloatEditor$method$setAsText$3108622962800f9f(_jc_env *, struct _jc_gnu_java_beans_editors_NativeFloatEditor$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_editors_NativeFloatEditor$method_info$getAsText$e78133031f0dd45a;
extern _jc_method _jc_gnu_java_beans_editors_NativeFloatEditor$method_info$setAsText$3108622962800f9f;

// Virtual methods structure
struct _jc_gnu_java_beans_editors_NativeFloatEditor$vmethods {
	struct _jc_java_lang_String$object	*(*getAsText$e78133031f0dd45a)(_jc_env *, struct _jc_gnu_java_beans_editors_NativeFloatEditor$object *) _JC_JCNI_ATTR;
	void	(*setAsText$3108622962800f9f)(_jc_env *, struct _jc_gnu_java_beans_editors_NativeFloatEditor$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_editors_NativeFloatEditor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_PropertyEditorSupport$vmethods	java_beans_PropertyEditorSupport;
	_jc_gnu_java_beans_editors_NativeFloatEditor$vmethods	gnu_java_beans_editors_NativeFloatEditor;
};

// Vtype
struct _jc_gnu_java_beans_editors_NativeFloatEditor$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_editors_NativeFloatEditor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_editors_NativeFloatEditor$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_editors_NativeFloatEditor$refs {
    _jc_gnu_java_beans_editors_NativeFloatEditor$sub_refs	gnu_java_beans_editors_NativeFloatEditor;
    _jc_java_beans_PropertyEditorSupport$sub_refs	java_beans_PropertyEditorSupport;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_editors_NativeFloatEditor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_editors_NativeFloatEditor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_PropertyEditorSupport$sub_nonrefs	java_beans_PropertyEditorSupport;
    _jc_gnu_java_beans_editors_NativeFloatEditor$sub_nonrefs	gnu_java_beans_editors_NativeFloatEditor;
};

// Object instance structure
struct _jc_gnu_java_beans_editors_NativeFloatEditor$object {
	_jc_gnu_java_beans_editors_NativeFloatEditor$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_editors_NativeFloatEditor$vtype	*vtype;
	_jc_gnu_java_beans_editors_NativeFloatEditor$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_editors_NativeFloatEditor$vtype _jc_gnu_java_beans_editors_NativeFloatEditor$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_editors_NativeFloatEditor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_editors_NativeFloatEditor$class_object;

#endif	/* _JC_gnu_java_beans_editors_NativeFloatEditor_H_ */
